==> WeefPy-1.0.4.tar.gz: WeefPy-1.0.4/WeefPy/response.py <==
from datetime import datetime
from orjson import dumps


class Response:
	def __init__(self, res, default_content_type="application/json"):
		self.res = res
		self._body = ""
		self._status = ""
		self._content_type = default_content_type
		self.encoding = "UTF-8"
		self._location = ""
		self.headers = []

	def __call__(self):
		if self._content_type[0:4] == "text" or self._content_type[0:11] == "application":
			self.add_header('Content-Type', self._content_type + ";charset=" + self.encoding)
		else:
			self.add_header('Content-Type', self._content_type)
		self.add_header('Content-Length', str(len(self._body)))
		self.res(self._status, self.headers)

	def set(self, body, status=None, content_type=None):
		self._status = status or "200 OK"
		self._content_type = content_type or self._content_type
		if type(body) == bytes:
			self._body = body
		elif type(body) == str:
			self._body = bytes(body, self.encoding)
		else:
			self._body = dumps(body) if content_type == "application/json" else bytes(str(body), self.encoding)

	def redirect(self, location, status="302"):
		self._status = status
		self._location = location
		self.add_header('Location', location)

	def set_cookie(self, name, value, expires=None, maxAge=None, **kwargs):
		cookie = name + "=" + value
		if expires:
			if type(expires) == datetime:
				cookie += "; Expires=" + expires.strftime('%a, %d %b %Y %H:%M:%S %Z')
			else:
				cookie += "; Expires=" + expires
		elif maxAge:
			cookie += "; Max-Age=" + str(maxAge)
		for arg in kwargs:  # Domain=None, Path=None, Secure=False, HttpOnly=False
			cookie += "; " + arg[0].upper() + arg[1:] + "=" + kwargs[arg] if kwargs[arg] else "; " + arg[0].upper() + arg[1:]
		self.headers.append(("Set-Cookie", cookie))

	def add_header(self, name, value):
		self.headers.append((name, value))

	def get_body(self):
		return self._body

	def get_status(self):
		return self._status

	def get_content_type(self):
		return self._content_type

==> WeefPy-1.2.4.tar.gz: WeefPy-1.2.4/WeefPy/response.py <==
from datetime import datetime
from orjson import dumps


class Response:
	def __init__(self, res, content_type="application/json"):
		self.res = res
		self._body = ""
		self._status = ""
		self._type = content_type
		self.charset = "UTF-8"
		self._location = ""
		self.headers = []

	def __call__(self):
		if self._type[:4] == "text" or self._type[:11] == "application":
			self.add_header('Content-Type', self._type + ";charset=" + self.charset)
		else:
			self.add_header('Content-Type', self._type)
		self.add_header('Content-Length', str(len(self._body)))
		self.res(self._status, self.headers)
		return self._body

	def set(self, body, status=None, content_type=None):
		self._status = status or "200 OK"
		self._type = content_type or self._type
		if type(body) == bytes:
			self._body = body
		elif type(body) == str:
			self._body = bytes(body, self.charset)
		else:
			self._body = dumps(body) if self._type == "application/json" else bytes(str(body), self.charset)

	def redirect(self, location, status="302"):
		self._status = status
		self._location = location
		self.add_header('Location', location)

	def set_cookie(self, name, value, expires=None, maxAge=None, **kwargs):
		cookie = name + "=" + value
		if expires:
			if type(expires) == datetime:
				cookie += "; Expires=" + expires.strftime('%a, %d %b %Y %H:%M:%S %Z')
			else:
				cookie += "; Expires=" + expires
		elif maxAge:
			cookie += "; Max-Age=" + str(maxAge)
		for arg in kwargs:  # Domain=None, Path=None, Secure=False, HttpOnly=False
			cookie += "; " + arg[0].upper() + arg[1:] + "=" + kwargs[arg] if kwargs[arg] else "; " + arg[0].upper() + arg[1:]
		self.headers.append(("Set-Cookie", cookie))

	def add_header(self, name, value):
		self.headers.append((name, value))

	def get_body(self):
		return self._body

	def get_status(self):
		return self._status

	def get_content_type(self):
		return self._type
